/************************************************************************************
managementofareamapirs
Copyright (c) 2010, International Rescue System Institute
All rights reserved.

Contact us if you use this software for sell.
If you use this software not for sell, you can use this software under BSD license.
See the files LICENSE.TXT and LICENSE-BSD.TXT for more details.                     
************************************************************************************/

//***************************************************************************************//
//* map.h										*//
//***************************************************************************************//

//-- [ヘッダファイル二重読込防止処理]----------------------------------------------------//
#ifndef __MAP__											// 条件コンパイル開始
#define __MAP__											// 条件判断用定義セット
//---------------------------------------------------------------------------------------//


//-- [ヘッダファイル] -------------------------------------------------------------------//
//- fcntl.h		: fcntl								-//
//- signal.h		: sigaction, struct sigaction					-//
//- stdio.h		: printf, fflush						-//
//- stdlib.h		: exit								-//
//- string.h		: strlen							-//
//- unisted.h		: close								-//
//- arpa/inet.h		: inet_addr							-//
//- netinet/in.h	: htons, inet_addr, struct sockaddr_in				-//
//- sys/socket.h	: inet_addr, recvfrom, sendto, socket				-//
//- sys/time.h		: gettimeofday							-//
//- sys/types.h		: recvfrom, sendto, socket					-//
//---------------------------------------------------------------------------------------//
#include <fcntl.h>										// fcntlヘッダファイル読み込み
#include <signal.h>										// signalヘッダファイル読み込み
#include <stdio.h>										// stdioヘッダファイル読み込み
#include <stdlib.h>										// stdlibヘッダファイル読み込み
#include <string.h>										// stringヘッダファイル読み込み
#include <sys/time.h>										// sys/timeヘッダファイル読み込み
#include <sys/types.h>										// sys/typesヘッダファイル読み込み
#include <sys/socket.h>										// sys/socketヘッダファイル読み込み
#include <netinet/in.h>										// netinet/inヘッダファイル読み込み
#include <arpa/inet.h>										// arpa/inetヘッダファイル読み込み
#include <unistd.h>										// unistdヘッダファイル読み込み
//---------------------------------------------------------------------------------------//


//-- [置換] -----------------------------------------------------------------------------//
#define BUFSIZE		512									// 最大送受信文字数
#define DATASIZE	256									// 最大データ文字数
//---------------------------------------------------------------------------------------//


//-- [型宣言] ---------------------------------------------------------------------------//
#pragma pack(1)											// 構造体パッキング

typedef struct BMPFILEHEADER{									// ファイルヘッダ
	unsigned short bfType;									// ファイルタイプ [BM]
	unsigned long  bfSize;									// ファイルサイズ [byte]
	unsigned short bfReserved1;								// 予約領域1 [0]
	unsigned short bfReserved2;								// 予約領域2 [0]
	unsigned long  bfOffBits;								// オフセットサイズ [byte]
}BMPFILEHEADER;

typedef struct BMPINFOHEADER{									// 情報ヘッダ
	unsigned long  biSize;									// 情報ヘッダサイズ [40 byte]
	long           biWidth;									// 画像幅 [pixel]
	long           biHeight;								// 画像高さ [pixel]
	unsigned short biPlanes;								// プレーン数 [1]
	unsigned short biBitCount;								// 色ビット数 [24]
	unsigned long  biCompression;								// 圧縮形式 [0]
	unsigned long  biSizeImage;								// 画像データサイズ [byte]
	long           biXPelsPerMeter;								// 水平解像度 [dot/m]
	long           biYPelsPerMeter;								// 垂直解像度 [dot/m]
	unsigned long  biClrUsed;								// 格納パレット数 [0]
	unsigned long  biClrImportant;								// 重要色数 [0]
}BMPINFOHEADER;

#pragma pack()											// 自然境界整列

typedef struct Category{									// カテゴリデータ
	unsigned long num;									// カテゴリ番号
	unsigned long rgb;									// RGB
	char category[256];									// カテゴリ
}Category;

typedef struct Picture{										// 画像データ
	int x;											// x軸画素数
	int y;											// y軸画素数
	unsigned char *r;									// RED要素   [0〜255]
	unsigned char *g;									// GREEN要素 [0〜255]
	unsigned char *b;									// BLUE要素  [0〜255]
	unsigned char *a;									// ALPHA要素 [0〜255]
}Picture;
//---------------------------------------------------------------------------------------//


//-- [プロトタイプ宣言] -----------------------------------------------------------------//
extern void signal_handler_IO(int);								// シグナル処理関数
extern double gettimeofday_sec();								// 時間確認関数
extern Picture* newpicture();									// 画像構造体メモリ確保関数
extern void deletepicture(Picture*);								// 画像構造体メモリ解放関数
extern Picture* getbitmap(FILE*);								// bitmap取得関数
//---------------------------------------------------------------------------------------//


//-- [変数宣言] -------------------------------------------------------------------------//
extern int wait_flag;										// フラグ格納変数 [読み込み専用]
//---------------------------------------------------------------------------------------//


//-- [ヘッダファイル末尾] ---------------------------------------------------------------//
#endif												// 条件コンパイル終了
//---------------------------------------------------------------------------------------//
